@@ -99,11 +99,6 @@ var _ = Describe("GPU instance support", func() {
 			gpuInstanceType:      "g4dn.xlarge",
 			expectUnsupportedErr: true,
 		}),
-		Entry("Windows2004", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyWindowsServer2004CoreContainer,
-			gpuInstanceType:      "p2.xlarge",
-			expectUnsupportedErr: true,
-		}),
 		Entry("Windows2019Core", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyWindowsServer2019CoreContainer,
 			gpuInstanceType:      "g3.8xlarge",
@@ -114,11 +109,6 @@ var _ = Describe("GPU instance support", func() {
 			gpuInstanceType:      "p3.2xlarge",
 			expectUnsupportedErr: true,
 		}),
-		Entry("Windows20H2Core", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyWindowsServer20H2CoreContainer,
-			gpuInstanceType:      "g4dn.xlarge",
-			expectUnsupportedErr: true,
-		}),
 	)
 	Describe("ARM GPU", func() {
 		When("ARM GPU instance is request for unmanaged nodegroups", func() {
