@@ -28,18 +28,18 @@ import (
 // Values for `KubernetesVersion`
 // All valid values should go in this block
 const (
-	Version1_19 = "1.19"
-
 	Version1_20 = "1.20"
 
 	Version1_21 = "1.21"
 
 	Version1_22 = "1.22"
 
+	Version1_23 = "1.23"
+
 	// DefaultVersion (default)
 	DefaultVersion = Version1_22
 
-	LatestVersion = Version1_22
+	LatestVersion = Version1_23
 )
 
 // No longer supported versions
@@ -55,6 +55,7 @@ const (
 
 	// Version1_13 represents Kubernetes version 1.13.x
 	Version1_13 = "1.13"
+
 	// Version1_14 represents Kubernetes version 1.14.x
 	Version1_14 = "1.14"
 
@@ -67,13 +68,17 @@ const (
 	// Version1_17 represents Kubernetes version 1.17.x
 	Version1_17 = "1.17"
 
+	// Version1_18 represents Kubernetes version 1.18.x
 	Version1_18 = "1.18"
+
+	// Version1_19 represents Kubernetes version 1.19.x
+	Version1_19 = "1.19"
 )
 
 // Not yet supported versions
 const (
-	// Version1_23 represents Kubernetes version 1.23.x
-	Version1_23 = "1.23"
+	// Version1_24 represents Kubernetes version 1.24.x
+	Version1_24 = "1.24"
 )
 
 const (
@@ -184,6 +189,10 @@ const (
 
 	NodeImageFamilyWindowsServer2019CoreContainer = "WindowsServer2019CoreContainer"
 	NodeImageFamilyWindowsServer2019FullContainer = "WindowsServer2019FullContainer"
+)
+
+// Deprecated `NodeAMIFamily`
+const (
 	NodeImageFamilyWindowsServer2004CoreContainer = "WindowsServer2004CoreContainer"
 	NodeImageFamilyWindowsServer20H2CoreContainer = "WindowsServer20H2CoreContainer"
 )
@@ -468,6 +477,7 @@ func DeprecatedVersions() []string {
 		Version1_16,
 		Version1_17,
 		Version1_18,
+		Version1_19,
 	}
 }
 
@@ -484,10 +494,10 @@ func IsDeprecatedVersion(version string) bool {
 // SupportedVersions are the versions of Kubernetes that EKS supports
 func SupportedVersions() []string {
 	return []string{
-		Version1_19,
 		Version1_20,
 		Version1_21,
 		Version1_22,
+		Version1_23,
 	}
 }
 
@@ -521,8 +531,6 @@ func supportedAMIFamilies() []string {
 		NodeImageFamilyBottlerocket,
 		NodeImageFamilyWindowsServer2019CoreContainer,
 		NodeImageFamilyWindowsServer2019FullContainer,
-		NodeImageFamilyWindowsServer2004CoreContainer,
-		NodeImageFamilyWindowsServer20H2CoreContainer,
 	}
 }
 
@@ -1346,7 +1354,7 @@ type NodeGroupBase struct {
 	// +optional
 	PrivateNetworking bool `json:"privateNetworking"`
 	// Applied to the Autoscaling Group and to the EC2 instances (unmanaged),
-	// Applied to the Autoscaling Group, the EKS Nodegroup resource and to the EC2 instances (managed)
+	// Applied to the EKS Nodegroup resource and to the EC2 instances (managed)
 	// +optional
 	Tags map[string]string `json:"tags,omitempty"`
 	// +optional
