@@ -503,6 +503,9 @@ func validateNodeGroupBase(np NodePool, path string) error {
 	}
 
 	if ng.AMIFamily != "" && !isSupportedAMIFamily(ng.AMIFamily) {
+		if ng.AMIFamily == NodeImageFamilyWindowsServer20H2CoreContainer || ng.AMIFamily == NodeImageFamilyWindowsServer2004CoreContainer {
+			return fmt.Errorf("AMI Family %s is deprecated. For more information, head to the Amazon documentation on Windows AMIs (https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-windows-ami.html)", ng.AMIFamily)
+		}
 		return fmt.Errorf("AMI Family %s is not supported - use one of: %s", ng.AMIFamily, strings.Join(supportedAMIFamilies(), ", "))
 	}
 
@@ -1243,9 +1246,7 @@ func isSupportedAMIFamily(imageFamily string) bool {
 func IsWindowsImage(imageFamily string) bool {
 	switch imageFamily {
 	case NodeImageFamilyWindowsServer2019CoreContainer,
-		NodeImageFamilyWindowsServer2019FullContainer,
-		NodeImageFamilyWindowsServer2004CoreContainer,
-		NodeImageFamilyWindowsServer20H2CoreContainer:
+		NodeImageFamilyWindowsServer2019FullContainer:
 		return true
 
 	default:
