@@ -715,7 +715,7 @@ func NewCreateIAMServiceAccountLoader(cmd *Cmd, saFilter *filter.IAMServiceAccou
 		}
 
 		if serviceAccount.AttachRoleARN != "" && (*serviceAccount.RoleOnly || serviceAccount.RoleName != "") {
-			return fmt.Errorf("cannot provde --role-name or --role-only when --attach-role-arn is configured")
+			return fmt.Errorf("cannot provide --role-name or --role-only when --attach-role-arn is configured")
 		}
 
 		if serviceAccount.AttachRoleARN != "" && (len(serviceAccount.AttachPolicyARNs) != 0 || serviceAccount.AttachPolicy != nil) {
